from monkey_island.cc.services.utils.typographic_symbols import WARNING_SIGN

EXPLOITER_CLASSES = {
    "title": "Exploit class",
    "description": "Click on exploiter to get more information about it." + WARNING_SIGN +
                   " Note that using unsafe exploits may cause crashes of the exploited machine/service.",
    "type": "string",
    "anyOf": [
        {
            "type": "string",
            "enum": [
                "SmbExploiter"
            ],
            "title": "SMB Exploiter",
            "attack_techniques": ["T1110", "T1075", "T1035"],
            "info": "Brute forces using credentials provided by user and"
                    " hashes gathered by mimikatz.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/smbexec/"
        },
        {
            "type": "string",
            "enum": [
                "WmiExploiter"
            ],
            "title": "WMI Exploiter",
            "attack_techniques": ["T1110", "T1106"],
            "info": "Brute forces WMI (Windows Management Instrumentation) "
                    "using credentials provided by user and hashes gathered by mimikatz.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/wmiexec/"
        },
        {
            "type": "string",
            "enum": [
                "MSSQLExploiter"
            ],
            "title": "MSSQL Exploiter",
            "attack_techniques": ["T1110"],
            "info": "Tries to brute force into MsSQL server and uses insecure "
                    "configuration to execute commands on server.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/mssql/"
        },
        {
            "type": "string",
            "enum": [
                "Ms08_067_Exploiter"
            ],
            "title": "MS08-067 Exploiter (UNSAFE)",
            "info": "Unsafe exploiter, that might cause system crash due to the use of buffer overflow. "
                    "Uses MS08-067 vulnerability.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/ms08-067/"
        },
        {
            "type": "string",
            "enum": [
                "SSHExploiter"
            ],
            "title": "SSH Exploiter",
            "attack_techniques": ["T1110", "T1145", "T1106"],
            "info": "Brute forces using credentials provided by user and SSH keys gathered from systems.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/sshexec/"
        },
        {
            "type": "string",
            "enum": [
                "ShellShockExploiter"
            ],
            "title": "ShellShock Exploiter",
            "info": "CVE-2014-6271, based on logic from "
                    "https://github.com/nccgroup/shocker/blob/master/shocker.py .",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/shellshock/"
        },
        {
            "type": "string",
            "enum": [
                "SambaCryExploiter"
            ],
            "title": "SambaCry Exploiter",
            "info": "Bruteforces and searches for anonymous shares. Uses Impacket.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/sambacry/"
        },
        {
            "type": "string",
            "enum": [
                "ElasticGroovyExploiter"
            ],
            "title": "ElasticGroovy Exploiter",
            "info": "CVE-2015-1427. Logic is based on Metasploit module.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/elasticgroovy/"
        },
        {
            "type": "string",
            "enum": [
                "Struts2Exploiter"
            ],
            "title": "Struts2 Exploiter",
            "info": "Exploits struts2 java web framework. CVE-2017-5638. Logic based on "
                    "https://www.exploit-db.com/exploits/41570 .",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/struts2/"
        },
        {
            "type": "string",
            "enum": [
                "WebLogicExploiter"
            ],
            "title": "WebLogic Exploiter",
            "info": "Exploits CVE-2017-10271 and CVE-2019-2725 vulnerabilities on WebLogic server.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/weblogic/"
        },
        {
            "type": "string",
            "enum": [
                "HadoopExploiter"
            ],
            "title": "Hadoop/Yarn Exploiter",
            "info": "Remote code execution on HADOOP server with YARN and default settings. "
                    "Logic based on https://github.com/vulhub/vulhub/tree/master/hadoop/unauthorized-yarn.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/hadoop/"
        },
        {
            "type": "string",
            "enum": [
                "VSFTPDExploiter"
            ],
            "title": "VSFTPD Exploiter",
            "info": "Exploits a malicious backdoor that was added to the VSFTPD download archive. "
                    "Logic based on Metasploit module.",
            "link": "https://www.guardicore.com/infectionmonkey/docs/reference/exploiters/vsftpd/"
        }
    ]
}
